
from setuptools import setup
from btcmarkets import __version__

setup(
    name="btcmarkets",
    packages=["btcmarkets"],
    version=__version__,
    description="Python wrapper for the BTCMarkets API",
    author="Bradley McElroy",
    author_email="bradley.mcelroy@live.com",
    url="https://github.com/limx0/btcmarkets",
)